@@ -11,20 +11,9 @@ import matplotlib.pyplot as plt
 
 from absbox import *
 from absbox.local.util import mkTag,DC,mkTs,query,consolStmtByDate,aggStmtByDate
-
 from absbox.local.component import *
 
 
-#data DealStats =
-#              | CurrentPoolDefaultedBalance
-#              | PoolCollectionInt  -- a redirect map to `CurrentPoolCollectionInt T.Day`
-#              | FutureOriginalPoolBalance
-#              | CurrentDueBondInt [String]
-#              | CurrentDueFee [String]
-#              | LastBondIntPaid [String]
-#              | LastFeePaid [String]
-
-
 def mkAssetRate(x):
     match x:
         case ["固定",r]:
@@ -32,6 +21,16 @@ def mkAssetRate(x):
         case ["浮动",r,{"基准":idx,"利差":spd,"重置频率":p}]:
             return mkTag(("Floater",[idx,spd,r,freqMap[p],None]))
 
+def mkAmortPlan(x):
+    match x:
+        case "等额本息" | "Level" :
+            return mkTag("Level")
+        case "等额本金" | "Even" :
+            return mkTag("Even")
+        case _ :
+            raise RuntimeError(f"Failed to match AmortPlan {x}")
+
+
 def mkAsset(x):
     _typeMapping = {"等额本息": "Level", "等额本金": "Even"}
     _statusMapping = {"正常": mkTag(("Current")), "违约": mkTag(("Defaulted",None))}
@@ -42,18 +41,19 @@ def mkAsset(x):
             ,{"当前余额": currentBalance
              ,"当前利率": currentRate
              ,"剩余期限": remainTerms
-             ,"状态": status}
-              ]:
-            return mkTag(("Mortgage",[{"originBalance": originBalance,
-                     "originRate": mkAssetRate(originRate),
-                     "originTerm": originTerm,
-                     "period": freqMap[freq],
-                     "startDate": startDate,
-                     "prinType": _typeMapping[_type]},
-                    currentBalance,
-                    currentRate,
-                    remainTerms,
-                    _statusMapping[status]
+             ,"状态": status}]:
+            return mkTag(("Mortgage",[
+                                      {"originBalance": originBalance,
+                                      "originRate": mkAssetRate(originRate),
+                                      "originTerm": originTerm,
+                                      "period": freqMap[freq],
+                                      "startDate": startDate,
+                                      "prinType": mkAmortPlan(_type)
+                                      } |mkTag("OriginalInfo"),
+                                     currentBalance,
+                                     currentRate,
+                                     remainTerms,
+                                     _statusMapping[status]
                     ]))
 
 def mkCf(x):
@@ -229,19 +229,6 @@ def mkAssumption(x):
         case {"停止": d}:
             return mkTag(("StopRunBy",d))
 
-# \"overrides\":[[{\"tag\":\"RunWaterfall\",\"contents\":[\"2022-01-01\",\"base\"]},{\"tag\":\"PoolCollection\",\"contents\":[\"0202-11-01\",\"collection\"]}]]}
-def mkOverrides(m):
-    return None
-#data WhenTrigger = EndCollection
-#                 | EndCollectionWF
-#                 | BeginDistributionWF
-#                 | EndDistributionWF
-
-# [
-#  [[\"BeginDistributionWF\",{\"tag\":\"AfterDate\",\"contents\":\"2022-03-01\"}]
-#    ,{\"tag\":\"DealStatusTo\",\"contents\":{\"tag\":\"Revolving\"}}]
-#   ]"
-
 def mkCustom(x):
     match x:
         case {"常量":n}:
@@ -257,17 +244,6 @@ def mk(x):
             return {"assets": [mkAsset(a) for a in assets]}
         case ["账户", accName, attrs]:
             return {accName: mkAcc(accName, attrs)}
-            #match attrs:
-            #    case {"余额": bal, "类型": accType}:
-            #        return {accName: {"accBalance": bal, "accName": accName
-            #                          , "accType": mkAccType(accType)
-            #                          , "accInterest": mkAccInt(attrs.get("计息",None))
-            #                          , "accStmt": mkAccTxn(attrs.get("记录",None))}}
-            #    case {"余额": bal}:
-            #        return { accName: {"accBalance": bal, "accName": accName
-            #                          , "accType": None
-            #                          , "accInterest": mkAccInt(attrs.get("计息",None))
-            #                          , "accStmt": mkAccTxn(attrs.get("记录",None))}}
         case ["费用", feeName, {"类型": feeType ,**fi}]:
             return {feeName: {"feeName": feeName, "feeType": mkFeeType(feeType), "feeStart":fi.get("起算日",None)
                              ,"feeDueDate":fi.get("计算日",None) , "feeDue": 0,
@@ -291,6 +267,9 @@ class 时间点(Enum):
     分配前 = "BeginDistributionWF"
     分配后 = "EndDistributionWF"
 
+
+
+
 @dataclass
 class 信贷ABS:
     名称: str
@@ -469,8 +448,24 @@ class 信贷ABS:
                         raise  RuntimeError("持仓系数大于1.0")
                     output['position'][k] = output['bonds'][k][['本金','利息','本息合计']].apply(lambda x:x*factor).round(4)
 
+
+        #Get bond defaulted amount 
+        output['result'] = {}
+        bond_defaults = [ (_x['contents'][0],_x['tag'],_x['contents'][1],_x['contents'][2]) for _x in resp[2] if _x['tag'] in set(['BondOutstanding','BondOutstandingInt' ])]
+        _bnds = list(resp[0]['bonds'].keys())
+        _bdefaults = pd.DataFrame(columns=['本金违约','利息违约',"起算余额"],index=_bnds)
+        _dmap = {'BondOutstanding':"本金违约","BondOutstandingInt":"利息违约"}
+        for bn,amt_type,amt,begBal in bond_defaults:
+            _bdefaults.loc[bn][_dmap[amt_type]] = amt
+            _bdefaults.loc[bn]['起算余额'] = begBal
+        _bdefaults.fillna(0,inplace=True)
+        _bdefaults['合计违约'] = _bdefaults['本金违约'] + _bdefaults['利息违约']
+        output['result']['bonds'] = _bdefaults.sort_index()
+
         return output
 
+SPV = 信贷ABS
+
 def loadAsset(fp, reader, astType):
     ''' load assets '''
     with open(fp, 'r') as f:
